import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/default_card/default_card.dart';
import 'package:softcorp_flutter_core/text_theme/text_theme.dart';

import '../constants.dart';

class DefaultFormField extends StatefulWidget {
  final TextEditingController textEditingController;
  final TextInputType textInputType;
  final String hint;
  final String label;
  final String? Function(String?)? validator;
  final BoxConstraints? constraints;
  final int? numberOfLines;
  final bool? disabled;
  final bool? addDefaultBorder;
  final Color? labelColor;
  final IconData? prefixIcon;
  final bool? obscureText;

  const DefaultFormField({
    Key? key,
    required this.textEditingController,
    required this.textInputType,
    required this.hint,
    required this.label,
    this.validator,
    this.addDefaultBorder,
    this.constraints,
    this.numberOfLines,
    this.disabled,
    this.labelColor,
    this.prefixIcon,
    this.obscureText,
  }) : super(key: key);
}

class _DefaultFormFieldState extends State<DefaultFormField>{
  bool isActive = false;
  Color shadowColor = defaultShadow;
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(7.5),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          caption(
            text: widget.label,
            context: context,
            color: widget.labelColor ?? defaultSubTitleColor,
          ),
          const SizedBox(height: 5),
          DefaultCard(
            onTap: (){},
            shadowColor: shadowColor,
            child: TextFormField(
              onTap: (){
                setState(() {
                  isActive = !isActive;
                  shadowColor = isActive == true ? softcorpPrimaryColor : defaultShadow;
                });
              },
              enabled: widget.disabled == null ? true : (widget.disabled),
              controller: widget.textEditingController,
              obscureText: widget.obscureText ?? false,
              keyboardType: widget.textInputType,
              style: const TextStyle(color: Colors.black),
              decoration: InputDecoration(
                hintText: widget.hint,
                hoverColor: Colors.white,
                hintStyle: const TextStyle(fontSize: 16, color: Colors.grey),
                filled: true,
                prefixIcon: widget.prefixIcon != null
                    ? Icon(
                  widget.prefixIcon,
                        size: 15,
                        color: defaultSubTitleColor,
                      )
                    : null,
                enabledBorder: widget.addDefaultBorder == true
                    ? const OutlineInputBorder(
                        borderSide: BorderSide(
                          color: defaultBorderColor,
                          width: defaultBorderWidth,
                        ),
                        borderRadius: BorderRadius.all(
                            Radius.circular(defaultCornerRadius)),
                      )
                    : const OutlineInputBorder(
                        borderSide: BorderSide(
                          color: Colors.transparent,
                          width: defaultBorderWidth,
                        ),
                        borderRadius: BorderRadius.all(
                          Radius.circular(defaultCornerRadius),
                        ),
                      ),
                focusedBorder: const OutlineInputBorder(
                  borderSide: BorderSide(
                      color: defaultPrimaryColor, width: defaultBorderWidth),
                  borderRadius: BorderRadius.all(
                    Radius.circular(defaultCornerRadius),
                  ),
                ),
                errorBorder: const OutlineInputBorder(
                  borderSide: BorderSide(
                      color: defaultDangerColor, width: defaultBorderWidth),
                  borderRadius:
                      BorderRadius.all(Radius.circular(defaultCornerRadius)),
                ),
                focusedErrorBorder: const OutlineInputBorder(
                  borderSide: BorderSide(
                      color: defaultDangerColor, width: defaultBorderWidth),
                  borderRadius:
                      BorderRadius.all(Radius.circular(defaultCornerRadius)),
                ),
                contentPadding: const EdgeInsets.all(16),
                fillColor: widget.disabled == true ? Colors.grey[200] : Colors.white,
              ),
              validator: widget.validator,
              maxLines: widget.obscureText == true ? 1 : widget.numberOfLines,
            ),
          ),
        ],
      ),
    );
  }
}
